@@ -11,7 +11,7 @@ class UpdatePayoutAccount:
         self.route = "/payoutaccount/update/" + app + "/"
 
     def Process(self, request):
-        #json_data = json.loads(request)
+        json_data = json.dumps(request)
         headers = {"Content-type": "application/json",
                    "Accept": "application/json"}
 
@@ -33,10 +33,13 @@ class UpdatePayoutAccount:
                 url_info.hostname, url_info.port or 80)
 
         try:
-            conn.request('POST', (self.route + id), request, headers)
+            conn.request('POST', (self.route + id), json_data, headers)
             response = conn.getresponse()
+            print("response status >>>" + response.status)
+            text = response.read().decode()
+            print("response text >>>" + text)
             if response.status == 200:
-                return json.loads(response.read().decode())
+                return json.loads(text)
             else:
                 return {
                     "code": response.status,
